@@ -1,4 +1,5 @@
 import copy
+import functools
 import json
 import logging
 import os
@@ -19,6 +20,19 @@ from .utils import (
 log = logging.getLogger(__name__)
 
 
+@functools.cache
+def _docker_compose_bin() -> list[str]:
+    """Return the docker-compose command. Either 'docker compose' or 'docker-compose'.
+
+    Support the compose plugin and the compose standalone binary.
+    """
+    try:
+        subprocess.run(["docker", "compose", "--help"], check=True, capture_output=True)
+        return ["docker", "compose"]
+    except subprocess.CalledProcessError:
+        return ["docker-compose"]
+
+
 def compose_up(
     compose_file: Path,
     force_recreate: bool = False,
@@ -26,7 +40,7 @@ def compose_up(
     build: bool = False,
 ) -> None:
     log.info("Starting all containers")
-    compose_cmd = ["docker-compose", "-f", str(compose_file), "up", "-d"]
+    compose_cmd = _docker_compose_bin() + ["-f", str(compose_file), "up", "-d"]
     if force_recreate:
         compose_cmd.append("--force-recreate")
     if remove_orphan:
@@ -38,18 +52,23 @@ def compose_up(
 
 def compose_restart(compose_file: Path, container: str) -> None:
     log.info(f"Restarting {container} container")
-    compose_cmd = ["docker-compose", "-f", str(compose_file), "restart", container]
+    compose_cmd = _docker_compose_bin() + [
+        "-f",
+        str(compose_file),
+        "restart",
+        container,
+    ]
     subprocess.run(compose_cmd)
 
 
 def compose_down(compose_file: Path) -> None:
     log.info("Stopping all containers")
-    compose_cmd = ["docker-compose", "-f", str(compose_file), "down"]
+    compose_cmd = _docker_compose_bin() + ["-f", str(compose_file), "down"]
     subprocess.run(compose_cmd)
 
 
 def compose_log_tail(compose_file: Path) -> Process:
-    compose_cmd = ["docker-compose", "-f", str(compose_file), "logs", "--follow"]
+    compose_cmd = _docker_compose_bin() + ["-f", str(compose_file), "logs", "--follow"]
     p = EndlessProcess(target=subprocess.run, args=(compose_cmd,))
     p.start()
     return p
@@ -58,7 +77,7 @@ def compose_log_tail(compose_file: Path) -> Process:
 def compose_list_projects() -> list[dict[str, Any]]:
     return json.loads(
         subprocess.run(
-            ["docker-compose", "ls", "--format", "json"],
+            _docker_compose_bin() + ["ls", "--format", "json"],
             capture_output=True,
             check=True,
         ).stdout
@@ -69,7 +88,7 @@ def compose_stop_project(project_name: str):
     log.info("Stopping running projects")
     for p in compose_list_projects():
         if p["Name"] == project_name:
-            subprocess.run(["docker-compose", "-f", p["ConfigFiles"], "down"])
+            subprocess.run(_docker_compose_bin() + ["-f", p["ConfigFiles"], "down"])
 
 
 def make_bundle(app_interface_path: Path, qontract_server_path: Path):
