@@ -1,11 +1,20 @@
 import logging
 from multiprocessing import Process
 from pathlib import Path
-from typing import Callable, Optional, Sequence, Tuple, Union
+from typing import (
+    Callable,
+    Optional,
+    Sequence,
+    Tuple,
+    Union,
+)
 
 from rich.logging import RichHandler
-from watchfiles import Change, DefaultFilter, watch
-
+from watchfiles import (
+    Change,
+    DefaultFilter,
+    watch,
+)
 
 log = logging.getLogger(__name__)
 
